@@ -82,7 +82,7 @@ class Float(Number):
         super(Float, self).__init__()
 
     def validate(self, value):
-        value = super(self, Float).validate(value)
+        value = super(Float, self).validate(value)
         return float(value)
 
 
@@ -119,30 +119,80 @@ class String(Type):
 
     """
 
-    def __init__(self):
+    def __init__(self, encoding=None):
         super(String, self).__init__()
+        self._encoding = encoding
 
     def validate(self, value):
-        return str(value)
+        if self._encoding is not None:
+            value = value.encode(self._encoding)
+        return value
+
 
     def cast(self, value):
         return value
 
 
-class Regex(String):
+class _BaseRegex(String):
 
-    """ A string base type validated against a regex.
+    """ Base class for regex types.
     """
 
-    def __init__(self, regex, error='value doesn\'t match'):
-        super(String, self).__init__()
+    def __init__(self, regex, error='value doesn\'t match', **kwargs):
+        super(_BaseRegex, self).__init__(**kwargs)
         self._regex = re.compile(regex)
         self._error = error
 
     def validate(self, value):
-        value = super(Regex, self).validate(value)
-        if not self._regex.match(value):
+        value = super(_BaseRegex, self).validate(value)
+        match = self._regex.match(value)
+        if match is None:
             raise ValidationError(self._error)
+        return match
+
+
+class Regex(_BaseRegex):
+
+    """ A string based type validated against a regex.
+    """
+
+    def validate(self, value):
+        value = super(Regex, self).validate(value)
+        return value.string
+
+
+class NamedRegex(_BaseRegex):
+
+    """ A string based type like Regex but returning named groups in dict.
+    """
+
+    def validate(self, value):
+        value = super(NamedRegex, self).validate(value)
+        return value.groupdict()
+
+
+class RegexPattern(String):
+
+    """ A re Python object.
+
+    :param flags: python re compile `flag <http://docs.python.org/library/re.html#re.compile>`_
+
+    Example in configuration::
+
+        match = '/[a-z]+(-[a-z]+)?\.css'
+    """
+
+    def __init__(self, flags=0, **kwargs):
+        super(RegexPattern, self).__init__(**kwargs)
+        self.flags = flags
+
+    def validate(self, value):
+        value = super(RegexPattern, self).validate(value)
+        # Try to compile regex object:
+        try:
+            value = re.compile(value, self.flags)
+        except re.error:
+            raise ValidationError('Bad format for regular expression')
         return value
 
 
@@ -161,10 +211,10 @@ class IPAddress(String):
         interface = "127.0.0.1"
     """
 
-    def __init__(self, version=None):
+    def __init__(self, version=None, **kwargs):
         if not IPADDR_ENABLED:
             raise RuntimeError('You must install the ipaddr package to use this type')
-        super(IPAddress, self).__init__()
+        super(IPAddress, self).__init__(**kwargs)
         self._version = version
 
     def validate(self, value):
@@ -228,13 +278,13 @@ class IPSocketAddress(String):
         interface = "0.0.0.0:80"
     """
 
-    def __init__(self, default_addr='127.0.0.1', default_port=None, version=None):
+    def __init__(self, default_addr='127.0.0.1', default_port=None, version=None, **kwargs):
         if not IPADDR_ENABLED:
             raise RuntimeError('You must install the ipaddr package to use this type')
         self._default_addr = default_addr
         self._default_port = default_port
         self._version = version
-        super(IPSocketAddress, self).__init__()
+        super(IPSocketAddress, self).__init__(**kwargs)
 
     def validate(self, value):
         raw_addr, _, raw_port = value.partition(':')
@@ -301,3 +351,35 @@ class IPSocketAddress(String):
 
         def to_udp_socket(self):
             return self.to_socket(socket.SOCK_DGRAM)
+
+
+class Eval(String):
+
+    """ A string base type evaluating string as Python expression.
+
+    Example in configuration::
+
+        sum = 'sum(range(3, 10))'
+
+    .. warning::
+        This type can be dangerous since any Python expression can be typed
+        by the user, like __import__("sys").exit(). Use it at your own risk.
+    """
+
+    def __init__(self, locals=None, globals=None, **kwargs):
+        super(Eval, self).__init__(**kwargs)
+        if locals is None:
+            self._locals = {}
+        else:
+            self._locals = locals
+        if globals is None:
+            self._globals = {}
+        else:
+            self._globals = globals
+
+    def validate(self, value):
+        value = super(Eval, self).validate(value)
+        try:
+            return eval(value, self._globals, self._locals)
+        except Exception as err:
+            raise ValidationError('Bad expression: %s' % err)
